%global momorel 4

Summary: The LAPACK libraries for numerical linear algebra.
Name: lapack
Version: 3.1.1
Release: %{momorel}m%{?dist}
License: see "http://www.netlib.org/lapack/lug/node13.html"
Group: Development/Libraries
URL: http://www.netlib.org/lapack/
# If you want the source, look for the files with the .gz prefix
Source0: http://www.netlib.org/lapack/lapack-%{version}.tgz 
NoSource: 0
Source2: Makefile.blas
Source3: Makefile.lapack
Source4: http://www.netlib.org/lapack/lapackqref.ps
Source5: http://www.netlib.org/blas/blasqr.ps
Source1000: run-tests.sh
Patch3: lapack-3.1.1-make.inc.patch
Obsoletes: lapack-man
BuildRequires: gcc-gfortran
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildPreReq: gcc-gfortran

%{?include_specopt}
%{?!do_test: %global do_test 0}

%description
LAPACK (Linear Algebra PACKage) is a standard library for numerical
linear algebra. LAPACK provides routines for solving systems of
simultaneous linear equations, least-squares solutions of linear
systems of equations, eigenvalue problems, and singular value
problems. Associated matrix factorizations (LU, Cholesky, QR, SVD,
Schur, and generalized Schur) and related computations (i.e.,
reordering of Schur factorizations and estimating condition numbers)
are also included. LAPACK can handle dense and banded matrices, but
not general sparse matrices. Similar functionality is provided for
real and complex matrices in both single and double precision. LAPACK
is coded in Fortran77 and built with gcc.

%package devel
Summary: LAPACK development libraries
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
LAPACK development libraries for applications that link statically.

%package -n blas
Summary: The BLAS (Basic Linear Algebra Subprograms) library.
Group: Development/Libraries
Obsoletes: lapack-blas blas-man

%description -n blas
BLAS (Basic Linear Algebra Subprograms) is a standard library which
provides a number of basic algorithms for numerical algebra. Man
pages for blas are available in the blas-man package.

%package -n blas-devel
Summary: LAPACK development libraries
Group: Development/Libraries
Requires: blas = %{version}-%{release}

%description -n blas-devel
BLAS development libraries for applications that link statically.

%prep
%setup -q
%setup -q -D -T
%patch3 -p1
cp -f INSTALL/make.inc.gfortran make.inc
cp -f %{SOURCE2} BLAS/SRC/Makefile
cp -f %{SOURCE3} SRC/Makefile

#Empty
rm -f man/manl/zbcon.l

%build

RPM_OPT_O_FLAGS=$(echo $RPM_OPT_FLAGS | sed 's|-O2|-O0|' | sed 's|-O3|-O0|')
RPM_OPT_FLAGS="$RPM_OPT_O_FLAGS"
export FC=gfortran

# Build BLAS
pushd BLAS/SRC
FFLAGS="$RPM_OPT_O_FLAGS" make dcabs1.o
FFLAGS="$RPM_OPT_FLAGS" CFLAGS="$RPM_OPT_FLAGS" make static
cp libblas.a ${RPM_BUILD_DIR}/%{name}-%{version}/
make clean
FFLAGS="$RPM_OPT_O_FLAGS -fPIC" make dcabs1.o
FFLAGS="$RPM_OPT_FLAGS -fPIC" CFLAGS="$RPM_OPT_FLAGS -fPIC" make shared
cp libblas.so.3.1.1 ${RPM_BUILD_DIR}/%{name}-%{version}/
popd

ln -s libblas.so.3.1.1 libblas.so

# Some files don't like -O2, but -Os is fine
RPM_OPT_SIZE_FLAGS=$(echo $RPM_OPT_FLAGS | sed 's|-O2|-Os|')

# Build the static dlamch, dsecnd, lsame, second, slamch bits
pushd INSTALL
make NOOPT="$RPM_OPT_SIZE_FLAGS" OPTS="$RPM_OPT_FLAGS"
popd

# Build the static lapack library
pushd SRC
make FFLAGS="$RPM_OPT_FLAGS" CFLAGS="$RPM_OPT_FLAGS" static
cp liblapack.a ${RPM_BUILD_DIR}/%{name}-%{version}/
popd

# Build the shared dlamch, dsecnd, lsame, second, slamch bits
pushd INSTALL
make clean
make NOOPT="$RPM_OPT_SIZE_FLAGS -fPIC" OPTS="$RPM_OPT_FLAGS -fPIC"
popd

# Build the shared lapack library
pushd SRC
make clean
make FFLAGS="$RPM_OPT_FLAGS -fPIC" CFLAGS="$RPM_OPT_FLAGS -fPIC" shared
cp liblapack.so.3.1.1 ${RPM_BUILD_DIR}/%{name}-%{version}/
popd

# Buuld the static with pic dlamch, dsecnd, lsame, second, slamch bits
pushd INSTALL
make clean
make NOOPT="$RPM_OPT_SIZE_FLAGS -fPIC" OPTS="$RPM_OPT_FLAGS -fPIC"
popd

# Build the static with pic lapack library
pushd SRC
make clean
make FFLAGS="$RPM_OPT_FLAGS -fPIC" CFLAGS="$RPM_OPT_FLAGS -fPIC" static
cp liblapack.a ${RPM_BUILD_DIR}/%{name}-%{version}/liblapack_pic.a
popd

cp %{SOURCE4} lapackqref.ps
cp %{SOURCE5} blasqr.ps

%install
rm -fr %{buildroot}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_mandir}/manl

for f in liblapack.so.3.1.1 libblas.so.3.1.1 libblas.a liblapack.a liblapack_pic.a; do
  cp -f $f %{buildroot}%{_libdir}/$f
done

find  manpages/blas/man/manl -type f -printf "%{_mandir}/manl/%f.*\n" > blasmans

# These are also in the BLAS package
rm -f manpages/man/manl/lsame.l*
rm -f manpages/man/manl/xerbla.l*
find manpages/man/manl -type f -printf "%{_mandir}/manl/%f.*\n" > lapackmans

cp -f manpages/blas/man/manl/* %{buildroot}%{_mandir}/manl
cp -f manpages/man/manl/* %{buildroot}%{_mandir}/manl

cd %{buildroot}%{_libdir}
ln -sf liblapack.so.3.1.1 liblapack.so
ln -sf liblapack.so.3.1.1 liblapack.so.3
ln -sf liblapack.so.3.1.1 liblapack.so.3.1
ln -sf libblas.so.3.1.1 libblas.so
ln -sf libblas.so.3.1.1 libblas.so.3
ln -sf libblas.so.3.1.1 libblas.so.3.1

%check
%if %{do_test}
sh %{SOURCE1000}
%endif

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post -n blas -p /sbin/ldconfig

%postun -n blas -p /sbin/ldconfig

%clean
rm -fr %{buildroot}

%files -f lapackmans
%defattr(-,root,root)
%doc README lapackqref.ps
%{_libdir}/liblapack.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/liblapack.so
%{_libdir}/liblapack*.a

%files -n blas -f blasmans
%defattr(-,root,root)
%doc blasqr.ps
%{_libdir}/libblas.so.*

%files -n blas-devel
%defattr(-,root,root,-)
%{_libdir}/libblas.so
%{_libdir}/libblas*.a

%changelog
* Mon Jul 28 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.1.1-4m)
- add testsuite
- revise RPM_OPT_FLAGS to avoid infinite loop issues

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.1.1-3m)
- rebuild against gcc43

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (3.1.1-2m)
- %%NoSource -> NoSource

* Thu May 31 2007 Masayuki SANO <nosanosa@momonga-linux.org>
- (3.1.1-1m)
- update to 3.1.1
- sync with Fedora (3.1.1-1)
- - * Fri May 25 2007 Tom "spot" Callaway <tcallawa@redhat.com> 3.1.1-1
- - bump to 3.1.1
- * Fri Jan  5 2007 Tom "spot" Callaway <tcallawa@redhat.com> 3.1.0-4
- - fix bugzillas 219740,219741
- * Wed Dec 20 2006 Tom "spot" Callaway <tcallawa@redhat.com> 3.1.0-3
- - make clean everywhere
- * Wed Dec 20 2006 Tom "spot" Callaway <tcallawa@redhat.com> 3.1.0-2
- - fix the Makefiles
- * Tue Nov 14 2006 Tom "spot" Callaway <tcallawa@redhat.com> 3.1.0-1
- - bump to 3.1.0

* Sat Nov 11 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (3.0-8m)
- sync with Fedora Extra (lapack-3.0-38.src.rpm)
- separated devel packages
- fix some bugs
- merge lapack-man and blas-man to lapack and blas package respectivery
-
- * Thu Sep 14 2006 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-38
- - bump for fc-6
- * Tue Feb 28 2006 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-37
- - bump for FC5
- * Mon Dec 19 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-36
- - bump for gcc4.1
- * Tue Nov 15 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-35
- - try not to patch files that do not exist
- * Tue Nov 15 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-34
- - finish fixing bz 143340
- * Thu Oct  6 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-33
- - fix bz 169558
- * Wed Sep 28 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-32
- - move to latest upstream 3.0 tarballs
- - add 8 missing BLAS functions from upstream blas tarball (bz 143340)
- * Thu Sep 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-31
- - actually install liblapack_pic.a
- * Wed Sep 14 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-30
- - make -devel packages
- - make liblapack_pic.a package
- - use dist tag
- * Thu Apr 14 2005 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-29
- - package moves to Fedora Extras, gcc4

* Sun Jan  1 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0-7m)
- enable gcc-4.1.

* Sun Feb  6 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (3.0-6m)
- enable x86_64.

* Tue Nov 25 2003 zunda <zunda at freeshell.org>
- (3.0-5m)
- adapt the License: preamble for the Momonga Linux license
  expression unification policy (draft)
- It seems that hte BLAS code is under the same license:
  `The BLAS are not strictly speaking part of LAPACK, but Fortran 77 code for
  the BLAS is distributed with LAPACK, ...' from
	http://www.netlib.org/lapack/lug/node11.html.

* Thu Dec 19 2002 YAMAZAKI Makoto <uomaster@nifty.com>
- (3.0-4m)
- add BuildPreReq: gcc-g77

* Tue Oct 30 2001 Toru Hoshina <t@kondara.org>
- (3.0-2k)

* Mon Aug 13 2001 Trond Eivind Glomsr?<teg@redhat.com> 3.0-12
- The man-pages for xerbla and lsame were in blas-man and lapack-man (#51605)

* Fri Jun  8 2001 Trond Eivind Glomsr?<teg@redhat.com>
- Reenable optimization for IA64

* Fri May 25 2001 Trond Eivind Glomsr?<teg@redhat.com>
- Add all patches from the LAPACK site as of 2001-05-25
- Use this workaround for IA64 instead
- Remove SPARC workaround
- Don't exclude IA64

* Thu Dec 07 2000 Trond Eivind Glomsr?<teg@redhat.com>
- rebuild for main distribution

* Mon Nov 20 2000 Trond Eivind Glomsr?<teg@redhat.com>
- add the LAPACK Quick Reference Guide to the docs
- add the BLAS Quick Reference Guide to the docs

* Tue Aug 01 2000 Trond Eivind Glomsr?<teg@redhat.com>
- fix lack of ldconfig in postuninstall script

* Mon Jul 24 2000 Prospector <prospector@redhat.com>
- rebuilt

* Mon Jul 10 2000 Trond Eivind Glomsr?<teg@redhat.com>
- updated with the latest updates (new tarfile..) from netlib 

* Thu Jun 15 2000 Trond Eivind Glomsr?<teg@redhat.com>
- use %%{_mandir}
- added some flags to work around SPARC compiler bug

* Wed Jan 19 2000 Tim Powers <timp@redhat.com>
- bzipped sources to conserve space

* Tue Jan  4 2000 Jeff Johnson <jbj@redhat.com>
- build for PowerTools 6.2.

* Sat Dec 25 1999 Joachim Frieben <jfrieben@hotmail.com>
- updated to version v3.0 + update as of Tue Nov 30 1999

* Sat Oct 23 1999 Joachim Frieben <jfrieben@hotmail.com>
- updated Red Hat makefiles to v3.0

* Mon Aug 2 1999 Tim Powers <timp@redhat.com>
- updated to v3.0
- built for 6.1

* Mon Apr 12 1999 Michael Maher <mike@redhat.com>
- built package for 6.0

* Sat Oct 24 1998 Jeff Johnson <jbj@redhat.com>
- new description/summary text.

* Fri Jul 17 1998 Jeff Johnson <jbj@redhat.com>
- repackage for powertools.

* Sun Feb 15 1998 Trond Eivind Glomsr?<teg@pvv.ntnu.no>
 [lapack-2.0-9]
 - No code updates, just built with a customized rpm -
   this should make dependencies right.

* Sat Feb 07 1998 Trond Eivind Glomsr?<teg@pvv.ntnu.no>
 [lapack-2.0-8]
 - Total rewrite of the spec file
 - Added my own makefiles - libs should build better,
   static libs should work (and be faster than they
	would be if they had worked earlier ;)
 - No patch necessary anymore.
 - Renamed lapack-blas and lapack-blas-man to
   blas and blas-man. "Obsoletes:" tag added.
   (oh - and as always: Dedicated to the girl I
   love, Eline Skirnisdottir)

* Sat Dec 06 1997 Trond Eivind Glomsr?<teg@pvv.ntnu.no>
 [lapack-2.0-7]
  - added a dependency to glibc, so people don't try with libc5

* Thu Nov 20 1997 Trond Eivind Glomsr?<teg@pvv.ntnu.no>
  [lapack-2.0-6]
  - removed etime.c
  - compiled with egcs, and for glibc 2.0

* Sun Oct 12 1997 Trond Eivind Glomsr?<teg@pvv.ntnu.no>
  [lapack-2.0-5]
  - added a changelog
  - cleaned up building of shared libs
  - now uses a BuildRoot
  - cleaned up the specfile
